@@ -82,10 +82,13 @@ class TestResourceSanity:
       },
     },
     'CallRouterResource': {
-      'get': {
-        'call_router_id': '123',
+      'list': {
+        'office_id': '123',
       },
-      'post': {
+      'get': {
+        'router_id': '123',
+      },
+      'create': {
         'name': 'Test Router',
         'routing_url': 'fakeurl.com/url',
         'office_id': '123',
@@ -95,7 +98,7 @@ class TestResourceSanity:
         'secret': '123',
       },
       'patch': {
-        'call_router_id': '123',
+        'router_id': '123',
         'name': 'Test Router',
         'routing_url': 'fakeurl.com/url',
         'office_id': '123',
@@ -105,10 +108,10 @@ class TestResourceSanity:
         'secret': '123',
       },
       'delete': {
-        'call_router_id': '123',
+        'router_id': '123',
       },
       'assign_number': {
-        'call_router_id': '123',
+        'router_id': '123',
         'area_code': '519',
       },
     },
@@ -263,6 +266,10 @@ class TestResourceSanity:
         'target_id': '123',
         'target_type': 'office',
       },
+      'format': {
+        'country_code': 'gb',
+        'number': '020 3048 4377',
+      },
     },
     'OfficeResource': {
       'list': {},
@@ -369,6 +376,96 @@ class TestResourceSanity:
         'export_id': '123',
       },
     },
+    'SubscriptionResource': {
+      'list_agent_status_event_subscriptions': {},
+      'get_agent_status_event_subscription': {
+        'subscription_id': '123',
+      },
+      'create_agent_status_event_subscription': {
+        'agent_type': 'callcenter',
+        'enabled': True,
+        'webhook_id': '1000',
+      },
+      'update_agent_status_event_subscription': {
+        'subscription_id': '123',
+        'agent_type': 'callcenter',
+        'enabled': True,
+        'webhook_id': '1000',
+      },
+      'delete_agent_status_event_subscription': {
+        'subscription_id': '123',
+      },
+      'list_call_event_subscriptions': {
+        'target_id': '123',
+        'target_type': 'room',
+      },
+      'get_call_event_subscription': {
+        'subscription_id': '123',
+      },
+      'create_call_event_subscription': {
+        'enabled': True,
+        'group_calls_only': False,
+        'target_id': '123',
+        'target_type': 'office',
+        'call_states': ['connected', 'queued'],
+        'webhook_id': '1000',
+      },
+      'update_call_event_subscription': {
+        'subscription_id': '123',
+        'enabled': True,
+        'group_calls_only': False,
+        'target_id': '123',
+        'target_type': 'office',
+        'call_states': ['connected', 'queued'],
+        'webhook_id': '1000',
+      },
+      'delete_call_event_subscription': {
+        'subscription_id': '123',
+      },
+      'list_contact_event_subscriptions': {},
+      'get_contact_event_subscription': {
+        'subscription_id': '123',
+      },
+      'create_contact_event_subscription': {
+        'contact_type': 'shared',
+        'enabled': True,
+        'webhook_id': '1000',
+      },
+      'update_contact_event_subscription': {
+        'subscription_id': '123',
+        'contact_type': 'shared',
+        'enabled': True,
+        'webhook_id': '1000',
+      },
+      'delete_contact_event_subscription': {
+        'subscription_id': '123',
+      },
+      'list_sms_event_subscriptions': {
+        'target_id': '123',
+        'target_type': 'room',
+      },
+      'get_sms_event_subscription': {
+        'subscription_id': '123',
+      },
+      'create_sms_event_subscription': {
+        'direction': 'outbound',
+        'enabled': True,
+        'target_id': '123',
+        'target_type': 'office',
+        'webhook_id': '1000',
+      },
+      'update_sms_event_subscription': {
+        'subscription_id': '123',
+        'direction': 'outbound',
+        'enabled': True,
+        'target_id': '123',
+        'target_type': 'office',
+        'webhook_id': '1000',
+      },
+      'delete_sms_event_subscription': {
+        'subscription_id': '123',
+      },
+    },
     'TranscriptResource': {
       'get': {
         'call_id': '123',
@@ -458,6 +555,24 @@ class TestResourceSanity:
         'user_id': '123',
       },
     },
+    'WebhookResource': {
+      'list_webhooks': {},
+      'get_webhook': {
+        'webhook_id': '123',
+      },
+      'create_webhook': {
+        'hook_url': 'https://test.com/subhook',
+        'secret': 'badsecret',
+      },
+      'update_webhook': {
+        'webhook_id': '123',
+        'hook_url': 'https://test.com/subhook',
+        'secret': 'badsecret',
+      },
+      'delete_webhook': {
+        'webhook_id': '123',
+      },
+    },
   }
 
   def get_method_example_kwargs(self, resource_instance, resource_method):
